CliRunner class
Runs the Splendid Code Quality CLI tool.
This class handles command-line argument parsing, command routing, and execution of quality analysis commands.
Constructors
- CliRunner()
- Creates a new CLI runner.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< String> arguments) → Future<int> -
Runs the CLI with the given command-line
arguments. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited