CognitiveResult class

Contains the results of a cognitive complexity analysis.

Constructors

CognitiveResult({required int complexity})
Creates a cognitive result with the given complexity value.
const

Properties

complexity int
The calculated cognitive complexity value.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited