complexity property
The calculated cognitive complexity value.
Higher values indicate code that is more difficult to understand. Values above 15 typically indicate code that should be refactored for better readability.
Implementation
final int complexity;