CyclomaticComplexityAnalyzer class
Analyzes Dart source code to calculate cyclomatic complexity.
Cyclomatic complexity measures the number of independent paths through a program's source code by counting decision points using AST analysis.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyze(
String sourceCode) → ComplexityResult - Analyzes the given Dart source code and returns complexity metrics.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited