depth_of_inheritance/depth_of_inheritance_analyzer library
Analyzes Dart source code to calculate depth of inheritance.
Classes
- DepthOfInheritanceAnalyzer
- Analyzes Dart source code to calculate depth of inheritance for classes.
- InheritanceResult
- Contains the results of a depth of inheritance analysis.