HalsteadResult class
Contains the results of a Halstead complexity analysis.
Constructors
- HalsteadResult({required int uniqueOperators, required int uniqueOperands, required int totalOperators, required int totalOperands, required int vocabulary, required int length, required double volume, required double difficulty, required double effort})
-
Creates a Halstead result with the calculated metrics.
const
Properties
- difficulty → double
-
Program difficulty: (n1 / 2) * (N2 / n2).
final
- effort → double
-
Program effort: difficulty * volume.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Program length: N1 + N2.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalOperands → int
-
Total number of operands (N2).
final
- totalOperators → int
-
Total number of operators (N1).
final
- uniqueOperands → int
-
Number of unique operands (n2).
final
- uniqueOperators → int
-
Number of unique operators (n1).
final
- vocabulary → int
-
Program vocabulary: n1 + n2.
final
- volume → double
-
Program volume: N * log2(n).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited