difficulty property
Program difficulty: (n1 / 2) * (N2 / n2).
Difficulty estimates how hard the program is to write or understand. Higher difficulty suggests code that is more error-prone.
Implementation
final double difficulty;
Program difficulty: (n1 / 2) * (N2 / n2).
Difficulty estimates how hard the program is to write or understand. Higher difficulty suggests code that is more error-prone.
final double difficulty;