effort property

double effort
final

Program effort: difficulty * volume.

Effort estimates the mental effort required to develop or understand the program. Higher effort indicates code that requires more cognitive resources.

Implementation

final double effort;