volume property
Program volume: N * log2(n).
Volume represents the size of the implementation and is measured in bits. Higher volume indicates more complex or verbose code.
Implementation
final double volume;
Program volume: N * log2(n).
Volume represents the size of the implementation and is measured in bits. Higher volume indicates more complex or verbose code.
final double volume;