LocAnalyzer class

Analyzes Dart source code to count lines of code.

This analyzer counts total lines, code lines (non-blank, non-comment), comment lines, and blank lines in Dart source files.

Constructors

LocAnalyzer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyze(String sourceCode) LocResult
Analyzes the given Dart source code and returns line count metrics.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited