LocResult class

Contains the results of a lines of code analysis.

Constructors

LocResult({required int totalLines, required int codeLines, required int commentLines, required int blankLines})
Creates a LOC result with the given line counts.
const

Properties

blankLines int
Number of blank lines.
final
codeLines int
Number of lines containing code (non-blank, non-comment).
final
commentLines int
Number of lines containing only comments.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalLines int
Total number of lines in the file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited