FileMetrics class

Contains all quality metrics for a single file.

Constructors

FileMetrics({required String filePath, required int cyclomaticComplexity, required int cognitiveComplexity, required int linesOfCode, required double halsteadVolume, required int depthOfInheritance})
Creates file metrics with the given values.
const

Properties

cognitiveComplexity int
Cognitive complexity score.
final
cognitiveComplexityStatus String
Returns the health status for cognitive complexity.
no setter
cyclomaticComplexity int
Cyclomatic complexity score.
final
cyclomaticComplexityStatus String
Returns the health status for cyclomatic complexity.
no setter
depthOfInheritance int
Maximum depth of inheritance.
final
depthOfInheritanceStatus String
Returns the health status for depth of inheritance.
no setter
filePath String
The file path.
final
halsteadVolume double
Halstead volume.
final
halsteadVolumeStatus String
Returns the health status for Halstead volume.
no setter
hashCode int
The hash code for this object.
no setterinherited
linesOfCode int
Lines of code (non-blank, non-comment).
final
linesOfCodeStatus String
Returns the health status for lines of code.
no setter
overallStatus String
Returns the overall health status (worst of all metrics).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited