InheritanceResult class
Contains the results of a depth of inheritance analysis.
Constructors
-
InheritanceResult({required int maxDepth, required Map<
String, int> classDepths}) -
Creates an inheritance result with the calculated metrics.
const
Properties
-
classDepths
→ Map<
String, int> -
Map of class names to their inheritance depths.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDepth → int
-
The maximum depth of inheritance found in the analyzed code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited